.. _median:

*****************************
Median Image Computation Step
*****************************
A median image gets generated from the stack of undistorted single
drizzle images.

.. moduleauthor:: Warren Hack <help@stsci.edu>

.. automodule:: drizzlepac.createMedian
   :members:
   :undoc-members:

